/* BitlBee settings, generated by configure
   
   Do *NOT* use any of these defines in your code without thinking twice, most
   of them can/will be overridden at run-time */

#define BITLBEE_CONFIGURE_ARGS "--bindir=/usr/local/libexec --mandir=/usr/local/man --config=/var/bitlbee --pidfile=/var/bitlbee/bitlbee.pid --etcdir=/etc/bitlbee --ssl=openssl --pie=0 --purple=1"

#define CONFIG "/var/bitlbee/"
#define ETCDIR "/etc/bitlbee/"
#define VARDIR "/usr/local/share/bitlbee/"
#define PLUGINDIR "/usr/local/lib/bitlbee/"
#define DATADIR "/usr/local/share/bitlbee/"
#define PIDFILE "/var/bitlbee/bitlbee.pid"
#define IPCSOCKET ""
#define EVENTS_GLIB
#define HAVE_RESOLV_A
#undef WITH_PAM
#undef WITH_LDAP
#define WITH_PLUGINS
#define WITH_PURPLE
#undef PACKAGE
#define PACKAGE "BitlBee-LIBPURPLE"
#undef WITH_JABBER
#define WITH_TWITTER
